@@ -10,6 +10,8 @@ using JuMP
 lpsolver = tuple()
 
 include("utils.jl")
+include("redundant.jl")
+include("adjacency.jl")
 include("simplex.jl")
 include("permutahedron.jl")
 include("board.jl")
